brightness_pillars: Get the brightness of pillars of a 3d array.
Description
For a 3-dimensional array mat3d, pillar ij is defined as mat3d[i, j, ].
This function computes the brightness of each pillar. Brightness is variance / mean.
Usage
brightness_pillars(arr3d, parallel = FALSE)
Arguments
arr3d
A 3-dimensional array.
parallel
Do you want to parallelize the computation across multiple
cores? If so, set this to the number of cores that you would like to use,
or set it to TRUE to use all available cores.
Value
A matrix where element i,j is equal to var(mat3d[i, j, ]) / mean(mat3d[i, j, ]).